import { ContractTransaction, BigNumber } from 'ethers';
import { Timestamp } from '@energyweb/utils-general';
import { IShareInCertificate } from './CertificateUtils';
import { IBlockchainProperties } from './BlockchainProperties';
import { IOwnershipCommitmentProofWithTx } from '../utils/PreciseProofUtils';
export interface IClaimData {
    beneficiary?: string;
    address?: string;
    region?: string;
    zipCode?: string;
    countryCode?: string;
}
export interface IClaim {
    id: number;
    from: string;
    to: string;
    topic: number;
    value: number;
    claimData: IClaimData;
}
export interface ICertificate {
    id: number;
    issuer: string;
    deviceId: string;
    generationStartTime: number;
    generationEndTime: number;
    certificationRequestId: number;
    creationTime: number;
    creationBlockHash: string;
    owners: IShareInCertificate;
    claimers: IShareInCertificate;
}
export declare class Certificate implements ICertificate {
    id: number;
    blockchainProperties: IBlockchainProperties;
    deviceId: string;
    generationStartTime: number;
    generationEndTime: number;
    issuer: string;
    creationTime: number;
    creationBlockHash: string;
    certificationRequestId: number;
    initialized: boolean;
    data: string;
    owners: IShareInCertificate;
    claimers: IShareInCertificate;
    constructor(id: number, blockchainProperties: IBlockchainProperties);
    static create(to: string, value: BigNumber, fromTime: Timestamp, toTime: Timestamp, deviceId: string, blockchainProperties: IBlockchainProperties): Promise<Certificate>;
    static createPrivate(to: string, value: BigNumber, fromTime: Timestamp, toTime: Timestamp, deviceId: string, blockchainProperties: IBlockchainProperties): Promise<{
        certificate: Certificate;
        proof: IOwnershipCommitmentProofWithTx;
    }>;
    sync(): Promise<Certificate>;
    claim(claimData: IClaimData, amount?: BigNumber, to?: string, from?: string): Promise<ContractTransaction>;
    transfer(to: string, amount?: BigNumber, from?: string): Promise<ContractTransaction>;
    revoke(): Promise<ContractTransaction>;
    isRevoked(): Promise<boolean>;
    getClaimedData(): Promise<IClaim[]>;
}
